@@ -1,25 +1,24 @@
-import threading
-import sys
-import time
-from math import inf
-import platform
+import contextvars
 import functools
+import platform
+import sys
+import threading
+import time
 import warnings
 from contextlib import contextmanager
-import gc
+from math import inf
 
-import pytest
 import attr
+import pytest
 
 from .tutil import check_sequence_matches, gc_collect_harder
+from ... import _core
+from ..._timeouts import sleep
 from ...testing import (
     wait_all_tasks_blocked,
     Sequencer,
     assert_checkpoints,
 )
-from ..._timeouts import sleep
-
-from ... import _core
 
 
 # slightly different from _timeouts.sleep_forever because it returns the value
@@ -185,9 +184,8 @@ def test_main_and_task_both_crash():
     with pytest.raises(_core.MultiError) as excinfo:
         _core.run(main)
     print(excinfo.value)
-    assert set(type(exc) for exc in excinfo.value.exceptions) == {
-        ValueError, KeyError
-    }
+    assert set(type(exc)
+               for exc in excinfo.value.exceptions) == {ValueError, KeyError}
 
 
 def test_two_child_crashes():
@@ -201,9 +199,8 @@ def test_two_child_crashes():
 
     with pytest.raises(_core.MultiError) as excinfo:
         _core.run(main)
-    assert set(type(exc) for exc in excinfo.value.exceptions) == {
-        ValueError, KeyError
-    }
+    assert set(type(exc)
+               for exc in excinfo.value.exceptions) == {ValueError, KeyError}
 
 
 async def test_child_crash_wakes_parent():
@@ -279,6 +276,11 @@ async def test_current_task():
         nursery.start_soon(child)
 
 
+async def test_root_task():
+    root = _core.current_root_task()
+    assert root.parent_nursery is None
+
+
 def test_out_of_context():
     with pytest.raises(RuntimeError):
         _core.current_task()
@@ -1203,8 +1205,10 @@ async def test_TrioToken_run_sync_soon_idempotent():
         for i in range(100):
             token.run_sync_soon(cb, i, idempotent=True)
     await wait_all_tasks_blocked()
-    if (sys.version_info < (3, 6)
-            and platform.python_implementation() == "CPython"):
+    if (
+        sys.version_info < (3, 6)
+        and platform.python_implementation() == "CPython"
+    ):
         # no order guarantees
         record.sort()
     # Otherwise, we guarantee FIFO
@@ -1553,8 +1557,12 @@ def test_nice_error_on_bad_calls_to_run_or_spawn():
 
             import asyncio
 
+            @asyncio.coroutine
+            def generator_based_coro():  # pragma: no cover
+                yield from asyncio.sleep(1)
+
             with pytest.raises(TypeError) as excinfo:
-                bad_call(asyncio.sleep(1))
+                bad_call(generator_based_coro())
             assert "asyncio" in str(excinfo.value)
 
             with pytest.raises(TypeError) as excinfo:
@@ -1562,7 +1570,7 @@ def test_nice_error_on_bad_calls_to_run_or_spawn():
             assert "asyncio" in str(excinfo.value)
 
             with pytest.raises(TypeError) as excinfo:
-                bad_call(asyncio.sleep, 1)
+                bad_call(generator_based_coro)
             assert "asyncio" in str(excinfo.value)
 
             with pytest.raises(TypeError) as excinfo:
@@ -1801,3 +1809,57 @@ async def test_nursery_start_keeps_nursery_open(autojump_clock):
             nursery1.start_soon(start_sleep_then_crash, nursery2)
             await wait_all_tasks_blocked()
         assert _core.current_time() - t0 == 7
+
+
+def test_contextvar_support():
+    var = contextvars.ContextVar("test")
+    var.set("before")
+
+    assert var.get() == "before"
+
+    async def inner():
+        task = _core.current_task()
+        assert task.context.get(var) == "before"
+        assert var.get() == "before"
+        var.set("after")
+        assert var.get() == "after"
+        assert var in task.context
+        assert task.context.get(var) == "after"
+
+    _core.run(inner)
+    assert var.get() == "before"
+
+
+async def test_contextvar_multitask():
+    var = contextvars.ContextVar("test", default="hmmm")
+
+    async def t1():
+        assert var.get() == "hmmm"
+        var.set("hmmmm")
+        assert var.get() == "hmmmm"
+
+    async def t2():
+        assert var.get() == "hmmmm"
+
+    async with _core.open_nursery() as n:
+        n.start_soon(t1)
+        await wait_all_tasks_blocked()
+        assert var.get() == "hmmm"
+        var.set("hmmmm")
+        n.start_soon(t2)
+        await wait_all_tasks_blocked()
+
+
+def test_Cancelled_init():
+    check_Cancelled_error = pytest.raises(
+        RuntimeError, match='should not be raised directly'
+    )
+
+    with check_Cancelled_error:
+        raise _core.Cancelled
+
+    with check_Cancelled_error:
+        _core.Cancelled()
+
+    # private constructor should not raise
+    _core.Cancelled._init()
