@@ -1,15 +1,14 @@
-from functools import wraps as _wraps, partial as _partial
+import os as _os
 import socket as _stdlib_socket
 import sys as _sys
-import os as _os
-from contextlib import contextmanager as _contextmanager
-import errno as _errno
+from functools import wraps as _wraps
 
 import idna as _idna
 
 from . import _core
 from ._deprecate import deprecated
 from ._threads import run_sync_in_worker_thread
+from ._util import fspath
 
 __all__ = []
 
@@ -117,7 +116,8 @@ for _name in [
 # Overrides
 ################################################################
 
-_overrides = _core.RunLocal(hostname_resolver=None, socket_factory=None)
+_resolver = _core.RunVar("hostname_resolver")
+_socket_factory = _core.RunVar("socket_factory")
 
 
 @_add_to_all
@@ -148,8 +148,8 @@ def set_custom_hostname_resolver(hostname_resolver):
       The previous hostname resolver (which may be None).
 
     """
-    old = _overrides.hostname_resolver
-    _overrides.hostname_resolver = hostname_resolver
+    old = _resolver.get(None)
+    _resolver.set(hostname_resolver)
     return old
 
 
@@ -176,8 +176,8 @@ def set_custom_socket_factory(socket_factory):
       The previous socket factory (which may be None).
 
     """
-    old = _overrides.socket_factory
-    _overrides.socket_factory = socket_factory
+    old = _socket_factory.get(None)
+    _socket_factory.set(socket_factory)
     return old
 
 
@@ -233,7 +233,7 @@ async def getaddrinfo(host, port, family=0, type=0, proto=0, flags=0):
             # idna.encode will error out if the hostname has Capital Letters
             # in it; with uts46=True it will lowercase them instead.
             host = _idna.encode(host, uts46=True)
-    hr = _overrides.hostname_resolver
+    hr = _resolver.get(None)
     if hr is not None:
         return await hr.getaddrinfo(host, port, family, type, proto, flags)
     else:
@@ -260,7 +260,7 @@ async def getnameinfo(sockaddr, flags):
     :func:`set_custom_hostname_resolver`.
 
     """
-    hr = _overrides.hostname_resolver
+    hr = _resolver.get(None)
     if hr is not None:
         return await hr.getnameinfo(sockaddr, flags)
     else:
@@ -336,7 +336,7 @@ def socket(family=AF_INET, type=SOCK_STREAM, proto=0, fileno=None):
 
     """
     if fileno is None:
-        sf = _overrides.socket_factory
+        sf = _socket_factory.get(None)
         if sf is not None:
             return sf.socket(family, type, proto)
     stdlib_socket = _stdlib_socket.socket(family, type, proto, fileno)
@@ -462,8 +462,10 @@ class _SocketType(SocketType):
     async def bind(self, address):
         await _core.checkpoint()
         address = await self._resolve_local_address(address)
-        if (hasattr(_stdlib_socket, "AF_UNIX") and self.family == AF_UNIX
-                and address[0]):
+        if (
+            hasattr(_stdlib_socket, "AF_UNIX") and self.family == AF_UNIX
+            and address[0]
+        ):
             # Use a thread for the filesystem traversal (unless it's an
             # abstract domain socket)
             return await run_sync_in_worker_thread(self._sock.bind, address)
@@ -504,6 +506,11 @@ class _SocketType(SocketType):
                     "address should be a (host, port, [flowinfo, [scopeid]]) "
                     "tuple"
                 )
+        elif self._sock.family == AF_UNIX:
+            await _core.checkpoint()
+            # unwrap path-likes
+            return fspath(address)
+
         else:
             await _core.checkpoint()
             return address
@@ -524,8 +531,8 @@ class _SocketType(SocketType):
             if not self._sock.getsockopt(IPPROTO_IPV6, IPV6_V6ONLY):
                 flags |= AI_V4MAPPED
         gai_res = await getaddrinfo(
-            host, port, self._sock.family,
-            real_socket_type(self._sock.type), self._sock.proto, flags
+            host, port, self._sock.family, real_socket_type(self._sock.type),
+            self._sock.proto, flags
         )
         # AFAICT from the spec it's not possible for getaddrinfo to return an
         # empty list.
