@@ -11,8 +11,10 @@ def test_core_is_properly_reexported():
     for symbol in _core.__all__:
         found = 0
         for source in sources:
-            if (symbol in source.__all__
-                    and getattr(source, symbol) is getattr(_core, symbol)):
+            if (
+                symbol in source.__all__
+                and getattr(source, symbol) is getattr(_core, symbol)
+            ):
                 found += 1
         print(symbol, found)
         assert found == 1
